@@ -1,7 +1,7 @@
 from antlr4 import *
-from PytovLexer import PytovLexer
-from PytovParser import PytovParser
-from PytovVisitor import PytovVisitor
+from pytov.PytovLexer import PytovLexer
+from pytov.PytovParser import PytovParser
+from pytov.PytovVisitor import PytovVisitor
 from antlr4.tree.Tree import TerminalNodeImpl
 import argparse
 
